=================================
astrodendro.structure.Structure
=================================

.. currentmodule:: astrodendro.structure

.. autoclass:: Structure

   .. rubric:: Attributes

   .. autosummary::

      ~Structure.is_leaf
      ~Structure.is_branch
      ~Structure.vmin
      ~Structure.vmax
      ~Structure.height
      ~Structure.ancestor
      ~Structure.parent
      ~Structure.children
      ~Structure.descendants
      ~Structure.level
      ~Structure.newick

   .. rubric:: Methods

   .. autosummary::

      ~Structure.indices
      ~Structure.values
      ~Structure.get_npix
      ~Structure.get_peak
      ~Structure.sorted_leaves
      ~Structure.get_mask

   .. rubric:: Methods (detail)

   .. automethod:: Structure.indices
   .. automethod:: Structure.values
   .. automethod:: Structure.get_npix
   .. automethod:: Structure.get_peak
   .. automethod:: Structure.sorted_leaves
   .. automethod:: Structure.get_mask
